summaryrefslogtreecommitdiffstats
path: root/cpukit/score/src/rbtreefind.c
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>2011-08-02 19:25:59 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>2011-08-02 19:25:59 +0000
commit13c4f853e6655e6b1c759255bea4f63c77806cdc (patch)
tree6347f845f2761b7ea2863c44c672e83f40177c9e /cpukit/score/src/rbtreefind.c
parent2011-08-02 Ricardo Aguirre <el.mastin@ymail.com> (diff)
downloadrtems-13c4f853e6655e6b1c759255bea4f63c77806cdc.tar.bz2
2011-08-02 Joel Sherrill <joel.sherrill@oarcorp.com>
PR 1877/cpukit * libfs/src/imfs/imfs_mknod.c, libfs/src/imfs/memfile.c, sapi/inline/rtems/rbtree.inl, score/include/rtems/score/rbtree.h, score/inline/rtems/score/rbtree.inl, score/src/rbtree.c, score/src/rbtreefind.c, score/src/rbtreeinsert.c: Add comparison function for RBTrees.
Diffstat (limited to 'cpukit/score/src/rbtreefind.c')
-rw-r--r--cpukit/score/src/rbtreefind.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/cpukit/score/src/rbtreefind.c b/cpukit/score/src/rbtreefind.c
index 1002982342..904a5b87c8 100644
--- a/cpukit/score/src/rbtreefind.c
+++ b/cpukit/score/src/rbtreefind.c
@@ -21,11 +21,11 @@
* _RBTree_Find
*
* This kernel routine returns a pointer to the rbtree node containing the
- * given value within the given tree, if it exists, or NULL otherwise.
+ * given key within the given tree, if it exists, or NULL otherwise.
*
* Input parameters:
* the_rbtree - pointer to rbtree control
* the_value - value of the node to search for
*
* Output parameters:
* return_node - pointer to control header of rbtree
@@ -38,7 +38,7 @@
RBTree_Node *_RBTree_Find(
RBTree_Control *the_rbtree,
- unsigned int the_value
+ RBTree_Node *search_node
)
{
ISR_Level level;
@@ -46,7 +46,7 @@ RBTree_Node *_RBTree_Find(
return_node = NULL;
_ISR_Disable( level );
- return_node = _RBTree_Find_unprotected( the_rbtree, the_value );
+ return_node = _RBTree_Find_unprotected( the_rbtree, search_node );
_ISR_Enable( level );
return return_node;
}
@@ -21,11 +21,11 @@
* Input parameters:
* the_rbtree - pointer to rbtree control
- * the_value - value of the node to search for
+ * search_node - node with the key to search for
*
* Output parameters: